from rest_framework import serializers

from netbox.api.serializers import WritableNestedSerializer
from netbox_storage.models import Filesystem, Drive, Partition, MountedVolume, LinuxDevice


#
# Device
#
class NestedDeviceSerializer(WritableNestedSerializer):
    url = serializers.HyperlinkedIdentityField(
        view_name="plugins-api:netbox_storage-api:linuxdevice-detail"
    )

    class Meta:
        model = LinuxDevice
        fields = ["id", "url", "display", "device", "type"]


#
# Filesystem
#

class NestedFilesystemSerializer(WritableNestedSerializer):
    url = serializers.HyperlinkedIdentityField(
        view_name="plugins-api:netbox_storage-api:filesystem-detail"
    )

    class Meta:
        model = Filesystem
        fields = ["id", "url", "display", "filesystem"]


#
# Drive
#
class NestedDriveSerializer(WritableNestedSerializer):
    url = serializers.HyperlinkedIdentityField(
        view_name="plugins-api:netbox_storage-api:drive-detail"
    )

    class Meta:
        model = Drive
        fields = ["id", "url", "display", "size", "identifier"]


#
# Partition
#
class NestedPartitionSerializer(WritableNestedSerializer):
    url = serializers.HyperlinkedIdentityField(
        view_name="plugins-api:netbox_storage-api:partition-detail"
    )

    class Meta:
        model = Partition
        fields = ["id", "url", "display", "size", "device", "type"]


#
# Linux Volume
#
class NestedMountedVolumeSerializer(WritableNestedSerializer):
    url = serializers.HyperlinkedIdentityField(
        view_name="plugins-api:netbox_storage-api:mountedvolume-detail"
    )

    class Meta:
        model = MountedVolume
        fields = ["id", "url", "display", "mount_point"]


class NestedVolumeGroupSerializer(WritableNestedSerializer):
    url = serializers.HyperlinkedIdentityField(
        view_name="plugins-api:netbox_storage-api:volumegroup-detail"
    )

    class Meta:
        model = MountedVolume
        fields = ["id", "url", "display", "vg_name"]



from netbox.tables import (
    NetBoxTable,
    ToggleColumn,
)

from netbox_storage.models import VolumeGroup


class VolumeGroupTable(NetBoxTable):
    """Table for displaying VolumeGroup objects."""

    pk = ToggleColumn()

    class Meta(NetBoxTable.Meta):
        model = VolumeGroup
        fields = (
            "pk",
            "vg_name",
            "description",
        )
        default_columns = (
            "vg_name",
            "description",
        )



from netbox.views import generic

from netbox_storage.filters import LinuxDeviceFilter
from netbox_storage.forms import (
    LinuxDeviceImportForm,
    LinuxDeviceFilterForm,
    LinuxDeviceForm,
    LinuxDeviceBulkEditForm
)

from netbox_storage.models import LinuxDevice
from netbox_storage.tables import LinuxDeviceTable


class LinuxDeviceListView(generic.ObjectListView):
    queryset = LinuxDevice.objects.all()
    filterset = LinuxDeviceFilter
    filterset_form = LinuxDeviceFilterForm
    table = LinuxDeviceTable


class LinuxDeviceView(generic.ObjectView):
    queryset = LinuxDevice.objects.all()


class LinuxDeviceEditView(generic.ObjectEditView):

    queryset = LinuxDevice.objects.all()
    form = LinuxDeviceForm
    default_return_url = "plugins:netbox_storage:linuxdevice_list"


class LinuxDeviceDeleteView(generic.ObjectDeleteView):
    queryset = LinuxDevice.objects.all()
    default_return_url = "plugins:netbox_storage:linuxdevice_list"


class LinuxDeviceBulkImportView(generic.BulkImportView):
    queryset = LinuxDevice.objects.all()
    model_form = LinuxDeviceImportForm
    table = LinuxDeviceTable
    default_return_url = "plugins:netbox_storage:linuxdevice_list"


class LinuxDeviceBulkEditView(generic.BulkEditView):
    queryset = LinuxDevice.objects.all()
    filterset = LinuxDeviceFilter
    table = LinuxDeviceTable
    form = LinuxDeviceBulkEditForm


class LinuxDeviceBulkDeleteView(generic.BulkDeleteView):
    queryset = LinuxDevice.objects.all()
    table = LinuxDeviceTable



from netbox.views import generic

from netbox_storage.forms.template import LVMTemplateForm, DriveTemplateForm, \
    PartitionTemplateForm
from netbox_storage.models import TemplateConfigurationDrive, Partition, LogicalVolume


class LVMAddTemplateView(generic.ObjectEditView):
    queryset = LogicalVolume.objects.all()
    form = LVMTemplateForm
#    default_return_url = "plugins:netbox_storage:drive_list"


class AddTemplateDriveView(generic.ObjectEditView):
    queryset = TemplateConfigurationDrive.objects.all()
    form = DriveTemplateForm


class AddTemplatePartitionView(generic.ObjectEditView):
    queryset = Partition.objects.all()
    form = PartitionTemplateForm



from netbox.views import generic

from netbox_storage.filters import VolumeGroupFilter
from netbox_storage.forms import (
    #VolumeGroupImportForm,
    VolumeGroupFilterForm,
    VolumeGroupForm,
    #VolumeGroupBulkEditForm
)
from netbox_storage.models import VolumeGroup
from netbox_storage.tables import VolumeGroupTable


class VolumeGroupListView(generic.ObjectListView):
    queryset = VolumeGroup.objects.all()
    filterset = VolumeGroupFilter
    filterset_form = VolumeGroupFilterForm
    table = VolumeGroupTable


class VolumeGroupView(generic.ObjectView):
    queryset = VolumeGroup.objects.all()


class VolumeGroupEditView(generic.ObjectEditView):
    queryset = VolumeGroup.objects.all()
    form = VolumeGroupForm
    default_return_url = "plugins:netbox_storage:VolumeGroup_list"


class VolumeGroupDeleteView(generic.ObjectDeleteView):
    queryset = VolumeGroup.objects.all()
    default_return_url = "plugins:netbox_storage:VolumeGroup_list"

"""
class VolumeGroupBulkImportView(generic.BulkImportView):
    queryset = VolumeGroup.objects.all()
    model_form = VolumeGroupImportForm
    table = VolumeGroupTable
    default_return_url = "plugins:netbox_storage:VolumeGroup_list"


class VolumeGroupBulkEditView(generic.BulkEditView):
    queryset = VolumeGroup.objects.all()
    filterset = VolumeGroupFilter
    table = VolumeGroupTable
    form = VolumeGroupBulkEditForm


class VolumeGroupBulkDeleteView(generic.BulkDeleteView):
    queryset = VolumeGroup.objects.all()
    table = VolumeGroupTable
"""